v1

package
v1.2.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2026 License: MIT Imports: 5 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

var (
	CompressMethod_name = map[int32]string{
		0: "COMPRESS_METHOD_UNSPECIFIED",
		1: "COMPRESS_METHOD_POLYLINE",
	}
	CompressMethod_value = map[string]int32{
		"COMPRESS_METHOD_UNSPECIFIED": 0,
		"COMPRESS_METHOD_POLYLINE":    1,
	}
)

Enum value maps for CompressMethod.

var File_tzf_v1_tzinfo_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type CompressMethod

type CompressMethod int32
const (
	CompressMethod_COMPRESS_METHOD_UNSPECIFIED CompressMethod = 0
	CompressMethod_COMPRESS_METHOD_POLYLINE    CompressMethod = 1 // https://developers.google.com/maps/documentation/utilities/polylinealgorithm
)

func (CompressMethod) Descriptor

func (CompressMethod) Enum

func (x CompressMethod) Enum() *CompressMethod

func (CompressMethod) EnumDescriptor deprecated

func (CompressMethod) EnumDescriptor() ([]byte, []int)

Deprecated: Use CompressMethod.Descriptor instead.

func (CompressMethod) Number

func (CompressMethod) String

func (x CompressMethod) String() string

func (CompressMethod) Type

type CompressedInlinePoints added in v1.1.0

type CompressedInlinePoints struct {
	Points []byte `protobuf:"bytes,1,opt,name=points,proto3" json:"points,omitempty"` // polyline-encoded point sequence
	// contains filtered or unexported fields
}

CompressedInlinePoints stores a short inline ring segment as polyline bytes.

func (*CompressedInlinePoints) Descriptor deprecated added in v1.1.0

func (*CompressedInlinePoints) Descriptor() ([]byte, []int)

Deprecated: Use CompressedInlinePoints.ProtoReflect.Descriptor instead.

func (*CompressedInlinePoints) GetPoints added in v1.1.0

func (x *CompressedInlinePoints) GetPoints() []byte

func (*CompressedInlinePoints) ProtoMessage added in v1.1.0

func (*CompressedInlinePoints) ProtoMessage()

func (*CompressedInlinePoints) ProtoReflect added in v1.1.0

func (x *CompressedInlinePoints) ProtoReflect() protoreflect.Message

func (*CompressedInlinePoints) Reset added in v1.1.0

func (x *CompressedInlinePoints) Reset()

func (*CompressedInlinePoints) String added in v1.1.0

func (x *CompressedInlinePoints) String() string

type CompressedPolygon

type CompressedPolygon struct {
	Points []byte               `protobuf:"bytes,1,opt,name=points,proto3" json:"points,omitempty"`
	Holes  []*CompressedPolygon `protobuf:"bytes,2,rep,name=holes,proto3" json:"holes,omitempty"`
	// contains filtered or unexported fields
}

func (*CompressedPolygon) Descriptor deprecated

func (*CompressedPolygon) Descriptor() ([]byte, []int)

Deprecated: Use CompressedPolygon.ProtoReflect.Descriptor instead.

func (*CompressedPolygon) GetHoles

func (x *CompressedPolygon) GetHoles() []*CompressedPolygon

func (*CompressedPolygon) GetPoints

func (x *CompressedPolygon) GetPoints() []byte

func (*CompressedPolygon) ProtoMessage

func (*CompressedPolygon) ProtoMessage()

func (*CompressedPolygon) ProtoReflect

func (x *CompressedPolygon) ProtoReflect() protoreflect.Message

func (*CompressedPolygon) Reset

func (x *CompressedPolygon) Reset()

func (*CompressedPolygon) String

func (x *CompressedPolygon) String() string

type CompressedRingSegment added in v1.1.0

type CompressedRingSegment struct {

	// Types that are valid to be assigned to Content:
	//
	//	*CompressedRingSegment_Inline
	//	*CompressedRingSegment_EdgeForward
	//	*CompressedRingSegment_EdgeReversed
	Content isCompressedRingSegment_Content `protobuf_oneof:"content"`
	// contains filtered or unexported fields
}

CompressedRingSegment mirrors RingSegment with polyline-encoded inline points.

func (*CompressedRingSegment) Descriptor deprecated added in v1.1.0

func (*CompressedRingSegment) Descriptor() ([]byte, []int)

Deprecated: Use CompressedRingSegment.ProtoReflect.Descriptor instead.

func (*CompressedRingSegment) GetContent added in v1.1.0

func (x *CompressedRingSegment) GetContent() isCompressedRingSegment_Content

func (*CompressedRingSegment) GetEdgeForward added in v1.1.0

func (x *CompressedRingSegment) GetEdgeForward() int32

func (*CompressedRingSegment) GetEdgeReversed added in v1.1.0

func (x *CompressedRingSegment) GetEdgeReversed() int32

func (*CompressedRingSegment) GetInline added in v1.1.0

func (*CompressedRingSegment) ProtoMessage added in v1.1.0

func (*CompressedRingSegment) ProtoMessage()

func (*CompressedRingSegment) ProtoReflect added in v1.1.0

func (x *CompressedRingSegment) ProtoReflect() protoreflect.Message

func (*CompressedRingSegment) Reset added in v1.1.0

func (x *CompressedRingSegment) Reset()

func (*CompressedRingSegment) String added in v1.1.0

func (x *CompressedRingSegment) String() string

type CompressedRingSegment_EdgeForward added in v1.1.0

type CompressedRingSegment_EdgeForward struct {
	EdgeForward int32 `protobuf:"varint,2,opt,name=edge_forward,json=edgeForward,proto3,oneof"`
}

type CompressedRingSegment_EdgeReversed added in v1.1.0

type CompressedRingSegment_EdgeReversed struct {
	EdgeReversed int32 `protobuf:"varint,3,opt,name=edge_reversed,json=edgeReversed,proto3,oneof"`
}

type CompressedRingSegment_Inline added in v1.1.0

type CompressedRingSegment_Inline struct {
	Inline *CompressedInlinePoints `protobuf:"bytes,1,opt,name=inline,proto3,oneof"`
}

type CompressedSharedEdge added in v1.1.0

type CompressedSharedEdge struct {
	Id     int32  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Points []byte `protobuf:"bytes,2,opt,name=points,proto3" json:"points,omitempty"` // polyline-encoded point sequence
	// contains filtered or unexported fields
}

CompressedSharedEdge stores a shared boundary edge with its point sequence polyline-encoded (delta + zigzag, same algorithm as CompressedPolygon).

func (*CompressedSharedEdge) Descriptor deprecated added in v1.1.0

func (*CompressedSharedEdge) Descriptor() ([]byte, []int)

Deprecated: Use CompressedSharedEdge.ProtoReflect.Descriptor instead.

func (*CompressedSharedEdge) GetId added in v1.1.0

func (x *CompressedSharedEdge) GetId() int32

func (*CompressedSharedEdge) GetPoints added in v1.1.0

func (x *CompressedSharedEdge) GetPoints() []byte

func (*CompressedSharedEdge) ProtoMessage added in v1.1.0

func (*CompressedSharedEdge) ProtoMessage()

func (*CompressedSharedEdge) ProtoReflect added in v1.1.0

func (x *CompressedSharedEdge) ProtoReflect() protoreflect.Message

func (*CompressedSharedEdge) Reset added in v1.1.0

func (x *CompressedSharedEdge) Reset()

func (*CompressedSharedEdge) String added in v1.1.0

func (x *CompressedSharedEdge) String() string

type CompressedTimezone

type CompressedTimezone struct {
	Data []*CompressedPolygon `protobuf:"bytes,1,rep,name=data,proto3" json:"data,omitempty"`
	Name string               `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

CompressedTimezonesItem designed for binary file as small as possible.

func (*CompressedTimezone) Descriptor deprecated

func (*CompressedTimezone) Descriptor() ([]byte, []int)

Deprecated: Use CompressedTimezone.ProtoReflect.Descriptor instead.

func (*CompressedTimezone) GetData

func (x *CompressedTimezone) GetData() []*CompressedPolygon

func (*CompressedTimezone) GetName

func (x *CompressedTimezone) GetName() string

func (*CompressedTimezone) ProtoMessage

func (*CompressedTimezone) ProtoMessage()

func (*CompressedTimezone) ProtoReflect

func (x *CompressedTimezone) ProtoReflect() protoreflect.Message

func (*CompressedTimezone) Reset

func (x *CompressedTimezone) Reset()

func (*CompressedTimezone) String

func (x *CompressedTimezone) String() string

type CompressedTimezones

type CompressedTimezones struct {
	Method    CompressMethod        `protobuf:"varint,1,opt,name=method,proto3,enum=tzf.v1.CompressMethod" json:"method,omitempty"`
	Timezones []*CompressedTimezone `protobuf:"bytes,2,rep,name=timezones,proto3" json:"timezones,omitempty"`
	Version   string                `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

func (*CompressedTimezones) Descriptor deprecated

func (*CompressedTimezones) Descriptor() ([]byte, []int)

Deprecated: Use CompressedTimezones.ProtoReflect.Descriptor instead.

func (*CompressedTimezones) GetMethod

func (x *CompressedTimezones) GetMethod() CompressMethod

func (*CompressedTimezones) GetTimezones

func (x *CompressedTimezones) GetTimezones() []*CompressedTimezone

func (*CompressedTimezones) GetVersion

func (x *CompressedTimezones) GetVersion() string

func (*CompressedTimezones) ProtoMessage

func (*CompressedTimezones) ProtoMessage()

func (*CompressedTimezones) ProtoReflect

func (x *CompressedTimezones) ProtoReflect() protoreflect.Message

func (*CompressedTimezones) Reset

func (x *CompressedTimezones) Reset()

func (*CompressedTimezones) String

func (x *CompressedTimezones) String() string

type CompressedTopoPolygon added in v1.1.0

type CompressedTopoPolygon struct {
	Exterior []*CompressedRingSegment `protobuf:"bytes,1,rep,name=exterior,proto3" json:"exterior,omitempty"`
	Holes    []*CompressedTopoPolygon `protobuf:"bytes,2,rep,name=holes,proto3" json:"holes,omitempty"`
	// contains filtered or unexported fields
}

CompressedTopoPolygon mirrors TopoPolygon with compressed ring segments.

func (*CompressedTopoPolygon) Descriptor deprecated added in v1.1.0

func (*CompressedTopoPolygon) Descriptor() ([]byte, []int)

Deprecated: Use CompressedTopoPolygon.ProtoReflect.Descriptor instead.

func (*CompressedTopoPolygon) GetExterior added in v1.1.0

func (x *CompressedTopoPolygon) GetExterior() []*CompressedRingSegment

func (*CompressedTopoPolygon) GetHoles added in v1.1.0

func (*CompressedTopoPolygon) ProtoMessage added in v1.1.0

func (*CompressedTopoPolygon) ProtoMessage()

func (*CompressedTopoPolygon) ProtoReflect added in v1.1.0

func (x *CompressedTopoPolygon) ProtoReflect() protoreflect.Message

func (*CompressedTopoPolygon) Reset added in v1.1.0

func (x *CompressedTopoPolygon) Reset()

func (*CompressedTopoPolygon) String added in v1.1.0

func (x *CompressedTopoPolygon) String() string

type CompressedTopoTimezone added in v1.1.0

type CompressedTopoTimezone struct {
	Polygons []*CompressedTopoPolygon `protobuf:"bytes,1,rep,name=polygons,proto3" json:"polygons,omitempty"`
	Name     string                   `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

CompressedTopoTimezone mirrors TopoTimezone with compressed polygons.

func (*CompressedTopoTimezone) Descriptor deprecated added in v1.1.0

func (*CompressedTopoTimezone) Descriptor() ([]byte, []int)

Deprecated: Use CompressedTopoTimezone.ProtoReflect.Descriptor instead.

func (*CompressedTopoTimezone) GetName added in v1.1.0

func (x *CompressedTopoTimezone) GetName() string

func (*CompressedTopoTimezone) GetPolygons added in v1.1.0

func (x *CompressedTopoTimezone) GetPolygons() []*CompressedTopoPolygon

func (*CompressedTopoTimezone) ProtoMessage added in v1.1.0

func (*CompressedTopoTimezone) ProtoMessage()

func (*CompressedTopoTimezone) ProtoReflect added in v1.1.0

func (x *CompressedTopoTimezone) ProtoReflect() protoreflect.Message

func (*CompressedTopoTimezone) Reset added in v1.1.0

func (x *CompressedTopoTimezone) Reset()

func (*CompressedTopoTimezone) String added in v1.1.0

func (x *CompressedTopoTimezone) String() string

type CompressedTopoTimezones added in v1.1.0

type CompressedTopoTimezones struct {
	Method      CompressMethod            `protobuf:"varint,1,opt,name=method,proto3,enum=tzf.v1.CompressMethod" json:"method,omitempty"`
	SharedEdges []*CompressedSharedEdge   `protobuf:"bytes,2,rep,name=shared_edges,json=sharedEdges,proto3" json:"shared_edges,omitempty"`
	Timezones   []*CompressedTopoTimezone `protobuf:"bytes,3,rep,name=timezones,proto3" json:"timezones,omitempty"`
	Version     string                    `protobuf:"bytes,4,opt,name=version,proto3" json:"version,omitempty"`
	GridIndex   *GridIndex                `protobuf:"bytes,5,opt,name=grid_index,json=gridIndex,proto3" json:"grid_index,omitempty"`
	// contains filtered or unexported fields
}

CompressedTopoTimezones combines shared-edge deduplication with polyline coordinate compression. Shared edge point sequences and inline segments are stored as polyline bytes instead of repeated Point messages, significantly reducing file size on top of the deduplication savings. grid_index is an optional embedded 1°×1° candidate-reduction index built at compress time. When present, Finder uses it to skip full linear scans.

func (*CompressedTopoTimezones) Descriptor deprecated added in v1.1.0

func (*CompressedTopoTimezones) Descriptor() ([]byte, []int)

Deprecated: Use CompressedTopoTimezones.ProtoReflect.Descriptor instead.

func (*CompressedTopoTimezones) GetGridIndex added in v1.2.0

func (x *CompressedTopoTimezones) GetGridIndex() *GridIndex

func (*CompressedTopoTimezones) GetMethod added in v1.1.0

func (x *CompressedTopoTimezones) GetMethod() CompressMethod

func (*CompressedTopoTimezones) GetSharedEdges added in v1.1.0

func (x *CompressedTopoTimezones) GetSharedEdges() []*CompressedSharedEdge

func (*CompressedTopoTimezones) GetTimezones added in v1.1.0

func (x *CompressedTopoTimezones) GetTimezones() []*CompressedTopoTimezone

func (*CompressedTopoTimezones) GetVersion added in v1.1.0

func (x *CompressedTopoTimezones) GetVersion() string

func (*CompressedTopoTimezones) ProtoMessage added in v1.1.0

func (*CompressedTopoTimezones) ProtoMessage()

func (*CompressedTopoTimezones) ProtoReflect added in v1.1.0

func (x *CompressedTopoTimezones) ProtoReflect() protoreflect.Message

func (*CompressedTopoTimezones) Reset added in v1.1.0

func (x *CompressedTopoTimezones) Reset()

func (*CompressedTopoTimezones) String added in v1.1.0

func (x *CompressedTopoTimezones) String() string

type GridIndex added in v1.2.0

type GridIndex struct {
	Cells   []*GridIndexCell `protobuf:"bytes,1,rep,name=cells,proto3" json:"cells,omitempty"`
	Version string           `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

GridIndex is the complete 1°×1° candidate-reduction index. Only cells with at least one intersecting timezone are stored.

func (*GridIndex) Descriptor deprecated added in v1.2.0

func (*GridIndex) Descriptor() ([]byte, []int)

Deprecated: Use GridIndex.ProtoReflect.Descriptor instead.

func (*GridIndex) GetCells added in v1.2.0

func (x *GridIndex) GetCells() []*GridIndexCell

func (*GridIndex) GetVersion added in v1.2.0

func (x *GridIndex) GetVersion() string

func (*GridIndex) ProtoMessage added in v1.2.0

func (*GridIndex) ProtoMessage()

func (*GridIndex) ProtoReflect added in v1.2.0

func (x *GridIndex) ProtoReflect() protoreflect.Message

func (*GridIndex) Reset added in v1.2.0

func (x *GridIndex) Reset()

func (*GridIndex) String added in v1.2.0

func (x *GridIndex) String() string

type GridIndexCell added in v1.2.0

type GridIndexCell struct {
	Lng       int32    `protobuf:"zigzag32,1,opt,name=lng,proto3" json:"lng,omitempty"` // floor(longitude), -180..179
	Lat       int32    `protobuf:"zigzag32,2,opt,name=lat,proto3" json:"lat,omitempty"` // floor(latitude), -90..89
	TzIndices []uint32 `protobuf:"varint,3,rep,packed,name=tz_indices,json=tzIndices,proto3" json:"tz_indices,omitempty"`
	// contains filtered or unexported fields
}

GridIndexCell records the timezone indices that intersect a single 1°×1° cell. tz_indices are 0-based positions into the timezones array of the companion CompressedTopoTimezones (or Timezones) file, matching the order used by Finder.items.

func (*GridIndexCell) Descriptor deprecated added in v1.2.0

func (*GridIndexCell) Descriptor() ([]byte, []int)

Deprecated: Use GridIndexCell.ProtoReflect.Descriptor instead.

func (*GridIndexCell) GetLat added in v1.2.0

func (x *GridIndexCell) GetLat() int32

func (*GridIndexCell) GetLng added in v1.2.0

func (x *GridIndexCell) GetLng() int32

func (*GridIndexCell) GetTzIndices added in v1.2.0

func (x *GridIndexCell) GetTzIndices() []uint32

func (*GridIndexCell) ProtoMessage added in v1.2.0

func (*GridIndexCell) ProtoMessage()

func (*GridIndexCell) ProtoReflect added in v1.2.0

func (x *GridIndexCell) ProtoReflect() protoreflect.Message

func (*GridIndexCell) Reset added in v1.2.0

func (x *GridIndexCell) Reset()

func (*GridIndexCell) String added in v1.2.0

func (x *GridIndexCell) String() string

type InlinePoints added in v1.1.0

type InlinePoints struct {
	Points []*Point `protobuf:"bytes,1,rep,name=points,proto3" json:"points,omitempty"`
	// contains filtered or unexported fields
}

Wrapper for a sequence of inline points used inside a RingSegment oneof. (proto3 does not allow repeated fields directly in a oneof.)

func (*InlinePoints) Descriptor deprecated added in v1.1.0

func (*InlinePoints) Descriptor() ([]byte, []int)

Deprecated: Use InlinePoints.ProtoReflect.Descriptor instead.

func (*InlinePoints) GetPoints added in v1.1.0

func (x *InlinePoints) GetPoints() []*Point

func (*InlinePoints) ProtoMessage added in v1.1.0

func (*InlinePoints) ProtoMessage()

func (*InlinePoints) ProtoReflect added in v1.1.0

func (x *InlinePoints) ProtoReflect() protoreflect.Message

func (*InlinePoints) Reset added in v1.1.0

func (x *InlinePoints) Reset()

func (*InlinePoints) String added in v1.1.0

func (x *InlinePoints) String() string

type Point

type Point struct {
	Lng float32 `protobuf:"fixed32,1,opt,name=lng,proto3" json:"lng,omitempty"`
	Lat float32 `protobuf:"fixed32,2,opt,name=lat,proto3" json:"lat,omitempty"`
	// contains filtered or unexported fields
}

Basic point data define.

func (*Point) Descriptor deprecated

func (*Point) Descriptor() ([]byte, []int)

Deprecated: Use Point.ProtoReflect.Descriptor instead.

func (*Point) GetLat

func (x *Point) GetLat() float32

func (*Point) GetLng

func (x *Point) GetLng() float32

func (*Point) ProtoMessage

func (*Point) ProtoMessage()

func (*Point) ProtoReflect

func (x *Point) ProtoReflect() protoreflect.Message

func (*Point) Reset

func (x *Point) Reset()

func (*Point) String

func (x *Point) String() string

type Polygon

type Polygon struct {
	Points []*Point   `protobuf:"bytes,1,rep,name=points,proto3" json:"points,omitempty"` // define the "exterior ring"
	Holes  []*Polygon `protobuf:"bytes,2,rep,name=holes,proto3" json:"holes,omitempty"`   // define the "interior rings" as holes
	// contains filtered or unexported fields
}

Define a polygon, mostly based on GeoJSON's Polygon define.

Excerpt from RFC-9476 section 'Polygon'

  • A linear ring is a closed LineString with four or more positions.

  • The first and last positions are equivalent, and they MUST contain identical values; their representation SHOULD also be identical.

  • A linear ring is the boundary of a surface or the boundary of a hole in a surface.

  • A linear ring MUST follow the right-hand rule with respect to the area it bounds, i.e., exterior rings are counterclockwise, and holes are clockwise.

    Note: the GJ2008 specification did not discuss linear ring winding order. For backwards compatibility, parsers SHOULD NOT reject Polygons that do not follow the right-hand rule.

    Though a linear ring is not explicitly represented as a GeoJSON geometry type, it leads to a canonical formulation of the Polygon geometry type definition as follows:

  • For type "Polygon", the "coordinates" member MUST be an array of linear ring coordinate arrays.

  • For Polygons with more than one of these rings, the first MUST be the exterior ring, and any others MUST be interior rings. The exterior ring bounds the surface, and the interior rings (if present) bound holes within the surface.

func (*Polygon) Descriptor deprecated

func (*Polygon) Descriptor() ([]byte, []int)

Deprecated: Use Polygon.ProtoReflect.Descriptor instead.

func (*Polygon) GetHoles

func (x *Polygon) GetHoles() []*Polygon

func (*Polygon) GetPoints

func (x *Polygon) GetPoints() []*Point

func (*Polygon) ProtoMessage

func (*Polygon) ProtoMessage()

func (*Polygon) ProtoReflect

func (x *Polygon) ProtoReflect() protoreflect.Message

func (*Polygon) Reset

func (x *Polygon) Reset()

func (*Polygon) String

func (x *Polygon) String() string

type PreindexTimezone

type PreindexTimezone struct {
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	X    int32  `protobuf:"varint,2,opt,name=x,proto3" json:"x,omitempty"`
	Y    int32  `protobuf:"varint,3,opt,name=y,proto3" json:"y,omitempty"`
	Z    int32  `protobuf:"varint,4,opt,name=z,proto3" json:"z,omitempty"`
	// contains filtered or unexported fields
}

PreindexTimezone tile item.

The X/Y/Z are OSM style like map tile index values.

func (*PreindexTimezone) Descriptor deprecated

func (*PreindexTimezone) Descriptor() ([]byte, []int)

Deprecated: Use PreindexTimezone.ProtoReflect.Descriptor instead.

func (*PreindexTimezone) GetName

func (x *PreindexTimezone) GetName() string

func (*PreindexTimezone) GetX

func (x *PreindexTimezone) GetX() int32

func (*PreindexTimezone) GetY

func (x *PreindexTimezone) GetY() int32

func (*PreindexTimezone) GetZ

func (x *PreindexTimezone) GetZ() int32

func (*PreindexTimezone) ProtoMessage

func (*PreindexTimezone) ProtoMessage()

func (*PreindexTimezone) ProtoReflect

func (x *PreindexTimezone) ProtoReflect() protoreflect.Message

func (*PreindexTimezone) Reset

func (x *PreindexTimezone) Reset()

func (*PreindexTimezone) String

func (x *PreindexTimezone) String() string

type PreindexTimezones

type PreindexTimezones struct {
	IdxZoom int32               `protobuf:"varint,1,opt,name=idx_zoom,json=idxZoom,proto3" json:"idx_zoom,omitempty"` // which zoom value the tiles generated
	AggZoom int32               `protobuf:"varint,2,opt,name=agg_zoom,json=aggZoom,proto3" json:"agg_zoom,omitempty"` // which zoom value the tiles merge up with.
	Keys    []*PreindexTimezone `protobuf:"bytes,3,rep,name=keys,proto3" json:"keys,omitempty"`
	Version string              `protobuf:"bytes,4,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

PreindexTimezones is all preindex timezone's dumps.

func (*PreindexTimezones) Descriptor deprecated

func (*PreindexTimezones) Descriptor() ([]byte, []int)

Deprecated: Use PreindexTimezones.ProtoReflect.Descriptor instead.

func (*PreindexTimezones) GetAggZoom

func (x *PreindexTimezones) GetAggZoom() int32

func (*PreindexTimezones) GetIdxZoom

func (x *PreindexTimezones) GetIdxZoom() int32

func (*PreindexTimezones) GetKeys

func (x *PreindexTimezones) GetKeys() []*PreindexTimezone

func (*PreindexTimezones) GetVersion

func (x *PreindexTimezones) GetVersion() string

func (*PreindexTimezones) ProtoMessage

func (*PreindexTimezones) ProtoMessage()

func (*PreindexTimezones) ProtoReflect

func (x *PreindexTimezones) ProtoReflect() protoreflect.Message

func (*PreindexTimezones) Reset

func (x *PreindexTimezones) Reset()

func (*PreindexTimezones) String

func (x *PreindexTimezones) String() string

type RingSegment added in v1.1.0

type RingSegment struct {

	// Types that are valid to be assigned to Content:
	//
	//	*RingSegment_Inline
	//	*RingSegment_EdgeForward
	//	*RingSegment_EdgeReversed
	Content isRingSegment_Content `protobuf_oneof:"content"`
	// contains filtered or unexported fields
}

A ring segment: either inline points or a reference to a shared edge. Shared edges are stored once in TopoTimezones.shared_edges and referenced by their index; edge_reversed references the same edge but traversed in the opposite direction.

func (*RingSegment) Descriptor deprecated added in v1.1.0

func (*RingSegment) Descriptor() ([]byte, []int)

Deprecated: Use RingSegment.ProtoReflect.Descriptor instead.

func (*RingSegment) GetContent added in v1.1.0

func (x *RingSegment) GetContent() isRingSegment_Content

func (*RingSegment) GetEdgeForward added in v1.1.0

func (x *RingSegment) GetEdgeForward() int32

func (*RingSegment) GetEdgeReversed added in v1.1.0

func (x *RingSegment) GetEdgeReversed() int32

func (*RingSegment) GetInline added in v1.1.0

func (x *RingSegment) GetInline() *InlinePoints

func (*RingSegment) ProtoMessage added in v1.1.0

func (*RingSegment) ProtoMessage()

func (*RingSegment) ProtoReflect added in v1.1.0

func (x *RingSegment) ProtoReflect() protoreflect.Message

func (*RingSegment) Reset added in v1.1.0

func (x *RingSegment) Reset()

func (*RingSegment) String added in v1.1.0

func (x *RingSegment) String() string

type RingSegment_EdgeForward added in v1.1.0

type RingSegment_EdgeForward struct {
	EdgeForward int32 `protobuf:"varint,2,opt,name=edge_forward,json=edgeForward,proto3,oneof"` // index into TopoTimezones.shared_edges (canonical direction)
}

type RingSegment_EdgeReversed added in v1.1.0

type RingSegment_EdgeReversed struct {
	EdgeReversed int32 `protobuf:"varint,3,opt,name=edge_reversed,json=edgeReversed,proto3,oneof"` // index into TopoTimezones.shared_edges (reversed direction)
}

type RingSegment_Inline added in v1.1.0

type RingSegment_Inline struct {
	Inline *InlinePoints `protobuf:"bytes,1,opt,name=inline,proto3,oneof"`
}

type SharedEdge added in v1.1.0

type SharedEdge struct {
	Id     int32    `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Points []*Point `protobuf:"bytes,2,rep,name=points,proto3" json:"points,omitempty"`
	// contains filtered or unexported fields
}

A shared boundary edge stored once in the global edge library. Rings reference it by index (forward or reversed) instead of repeating the point sequence.

func (*SharedEdge) Descriptor deprecated added in v1.1.0

func (*SharedEdge) Descriptor() ([]byte, []int)

Deprecated: Use SharedEdge.ProtoReflect.Descriptor instead.

func (*SharedEdge) GetId added in v1.1.0

func (x *SharedEdge) GetId() int32

func (*SharedEdge) GetPoints added in v1.1.0

func (x *SharedEdge) GetPoints() []*Point

func (*SharedEdge) ProtoMessage added in v1.1.0

func (*SharedEdge) ProtoMessage()

func (*SharedEdge) ProtoReflect added in v1.1.0

func (x *SharedEdge) ProtoReflect() protoreflect.Message

func (*SharedEdge) Reset added in v1.1.0

func (x *SharedEdge) Reset()

func (*SharedEdge) String added in v1.1.0

func (x *SharedEdge) String() string

type Timezone

type Timezone struct {
	Polygons []*Polygon `protobuf:"bytes,1,rep,name=polygons,proto3" json:"polygons,omitempty"`
	Name     string     `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Timezone is a timezone's all data.

func (*Timezone) Descriptor deprecated

func (*Timezone) Descriptor() ([]byte, []int)

Deprecated: Use Timezone.ProtoReflect.Descriptor instead.

func (*Timezone) GetName

func (x *Timezone) GetName() string

func (*Timezone) GetPolygons

func (x *Timezone) GetPolygons() []*Polygon

func (*Timezone) ProtoMessage

func (*Timezone) ProtoMessage()

func (*Timezone) ProtoReflect

func (x *Timezone) ProtoReflect() protoreflect.Message

func (*Timezone) Reset

func (x *Timezone) Reset()

func (*Timezone) String

func (x *Timezone) String() string

type Timezones

type Timezones struct {
	Timezones []*Timezone `protobuf:"bytes,1,rep,name=timezones,proto3" json:"timezones,omitempty"`
	Reduced   bool        `protobuf:"varint,2,opt,name=reduced,proto3" json:"reduced,omitempty"` // Reduced data will toggle neighbor search as plan b
	Version   string      `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

func (*Timezones) Descriptor deprecated

func (*Timezones) Descriptor() ([]byte, []int)

Deprecated: Use Timezones.ProtoReflect.Descriptor instead.

func (*Timezones) GetReduced

func (x *Timezones) GetReduced() bool

func (*Timezones) GetTimezones

func (x *Timezones) GetTimezones() []*Timezone

func (*Timezones) GetVersion

func (x *Timezones) GetVersion() string

func (*Timezones) ProtoMessage

func (*Timezones) ProtoMessage()

func (*Timezones) ProtoReflect

func (x *Timezones) ProtoReflect() protoreflect.Message

func (*Timezones) Reset

func (x *Timezones) Reset()

func (*Timezones) String

func (x *Timezones) String() string

type TopoPolygon added in v1.1.0

type TopoPolygon struct {
	Exterior []*RingSegment `protobuf:"bytes,1,rep,name=exterior,proto3" json:"exterior,omitempty"`
	Holes    []*TopoPolygon `protobuf:"bytes,2,rep,name=holes,proto3" json:"holes,omitempty"`
	// contains filtered or unexported fields
}

A timezone polygon in topology format. The exterior ring is represented as an ordered sequence of segments. Holes are nested TopoPolygons.

func (*TopoPolygon) Descriptor deprecated added in v1.1.0

func (*TopoPolygon) Descriptor() ([]byte, []int)

Deprecated: Use TopoPolygon.ProtoReflect.Descriptor instead.

func (*TopoPolygon) GetExterior added in v1.1.0

func (x *TopoPolygon) GetExterior() []*RingSegment

func (*TopoPolygon) GetHoles added in v1.1.0

func (x *TopoPolygon) GetHoles() []*TopoPolygon

func (*TopoPolygon) ProtoMessage added in v1.1.0

func (*TopoPolygon) ProtoMessage()

func (*TopoPolygon) ProtoReflect added in v1.1.0

func (x *TopoPolygon) ProtoReflect() protoreflect.Message

func (*TopoPolygon) Reset added in v1.1.0

func (x *TopoPolygon) Reset()

func (*TopoPolygon) String added in v1.1.0

func (x *TopoPolygon) String() string

type TopoTimezone added in v1.1.0

type TopoTimezone struct {
	Polygons []*TopoPolygon `protobuf:"bytes,1,rep,name=polygons,proto3" json:"polygons,omitempty"`
	Name     string         `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

A timezone in topology format.

func (*TopoTimezone) Descriptor deprecated added in v1.1.0

func (*TopoTimezone) Descriptor() ([]byte, []int)

Deprecated: Use TopoTimezone.ProtoReflect.Descriptor instead.

func (*TopoTimezone) GetName added in v1.1.0

func (x *TopoTimezone) GetName() string

func (*TopoTimezone) GetPolygons added in v1.1.0

func (x *TopoTimezone) GetPolygons() []*TopoPolygon

func (*TopoTimezone) ProtoMessage added in v1.1.0

func (*TopoTimezone) ProtoMessage()

func (*TopoTimezone) ProtoReflect added in v1.1.0

func (x *TopoTimezone) ProtoReflect() protoreflect.Message

func (*TopoTimezone) Reset added in v1.1.0

func (x *TopoTimezone) Reset()

func (*TopoTimezone) String added in v1.1.0

func (x *TopoTimezone) String() string

type TopoTimezones added in v1.1.0

type TopoTimezones struct {
	SharedEdges []*SharedEdge   `protobuf:"bytes,1,rep,name=shared_edges,json=sharedEdges,proto3" json:"shared_edges,omitempty"`
	Timezones   []*TopoTimezone `protobuf:"bytes,2,rep,name=timezones,proto3" json:"timezones,omitempty"`
	Version     string          `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
	// contains filtered or unexported fields
}

Timezones in topology format with shared-edge deduplication. Shared timezone boundaries are stored exactly once in shared_edges; rings reference them by ID rather than duplicating the point sequences. This format targets full-precision data where ~43% of boundary edges are shared, reducing the 96 MB full dataset by ~30–35 MB.

func (*TopoTimezones) Descriptor deprecated added in v1.1.0

func (*TopoTimezones) Descriptor() ([]byte, []int)

Deprecated: Use TopoTimezones.ProtoReflect.Descriptor instead.

func (*TopoTimezones) GetSharedEdges added in v1.1.0

func (x *TopoTimezones) GetSharedEdges() []*SharedEdge

func (*TopoTimezones) GetTimezones added in v1.1.0

func (x *TopoTimezones) GetTimezones() []*TopoTimezone

func (*TopoTimezones) GetVersion added in v1.1.0

func (x *TopoTimezones) GetVersion() string

func (*TopoTimezones) ProtoMessage added in v1.1.0

func (*TopoTimezones) ProtoMessage()

func (*TopoTimezones) ProtoReflect added in v1.1.0

func (x *TopoTimezones) ProtoReflect() protoreflect.Message

func (*TopoTimezones) Reset added in v1.1.0

func (x *TopoTimezones) Reset()

func (*TopoTimezones) String added in v1.1.0

func (x *TopoTimezones) String() string

Jump to